Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJoseph Eagar <joeedh@gmail.com>2006-11-20 14:07:56 +0300
committerJoseph Eagar <joeedh@gmail.com>2006-11-20 14:07:56 +0300
commit19a4f411723a08cded485cf694bbbab4a3dba31c (patch)
tree92cbcec24480fdcaaac6915b67d091cd75536d6b /source/blender/python/api2_2x/doc/Scene.py
parenta5a83ecd107b61f4440d77358ce25b7803a2f809 (diff)
=ID Properties Python Doc Update=
The epydocs are now updated to have idproperties; all the modules that have bindings for ID properties now has docs for them. E.g Materials have a .properties members, Image, Texture, Scene, Object, NMEsh, and Mesh. I realized that .properties was already taken in Objects, so I renamed it to .idproperties. There was also a nasty little problem with an example inside Object.getType; the entire example was being pasted inside the return field. I fixed it by just moving the return definition to after the example, like it should be.
Diffstat (limited to 'source/blender/python/api2_2x/doc/Scene.py')
-rw-r--r--source/blender/python/api2_2x/doc/Scene.py9
1 files changed, 7 insertions, 2 deletions
diff --git a/source/blender/python/api2_2x/doc/Scene.py b/source/blender/python/api2_2x/doc/Scene.py
index 35aeea8965f..31916b97ba6 100644
--- a/source/blender/python/api2_2x/doc/Scene.py
+++ b/source/blender/python/api2_2x/doc/Scene.py
@@ -73,12 +73,17 @@ def Unlink(scene):
@type scene: Blender Scene
@param scene: The Scene to be unlinked.
"""
-
+
+from IDProp import IDProperty, IDGroup, IDArray
class Scene:
"""
The Scene object
================
- This object gives access to Scene data in Blender.
+ This object gives access to Scene data in Blender.
+ @ivar properties: Returns an L{IDProperty<IDProperty>} reference of type L{IDGroup<IDGroup>} to
+ this scene's ID Properties. Note that dict access is available for groups on the parent
+ L{IDProperty<IDProperty>} object, but for everything else you need to get the L{IDGroup<IDGroup>}
+ object from the L{IDProperty<IDProperty>}'s data member.
@type name: string
@ivar name: The Scene name.
@type Layers: integer (bitmask)